CEMENTO — CEMENTO 0.8.5 documentation

Skip to main content
`Ctrl`+`K`

# CEMENTO

Version: 0.8.5

Useful links: Source Repository | Issue Tracker | MDS-Onto Website | PyPI Page

CEMENTO is a component python package of the larger SDLE FAIR application suite of tools for creating scientific ontologies more efficiently. This package provides functional interfaces for converting draw.io diagrams of ontologies into RDF triples in the turtle (`.ttl`) format and vice versa. This package is able to provide term matching between reference ontology files and terms used in draw.io diagrams allowing for faster ontology deployment while maintaining robust cross-references.

CEMENTO stands for the Centralized Entity Mapping & Extraction Nexus for Triples and Ontologies – a mouthful for an acronym, but an important metaphor for the package building the road to ontologies for materials data.

Quick Start

You just want to convert files? Check out our quick start guide and get yourself converting ontology diagrams and `.ttl` files immediately.

Guide

A detailed guide for using the CLI and the scripting tools.

API Reference

The full documentation for all things CEMENTO.

## Indices and tables

- Index

- Module Index

- Search Page